pub struct Beginning;Trait Implementations
Sourceimpl<I: HaystackItem> Matcher<I> for Beginning
impl<I: HaystackItem> Matcher<I> for Beginning
Sourcefn matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> bool
fn matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> bool
Checks if the start of the haystack contains a match for this
Matcher. If this method
successfully matches the start of the haystack, hay is progressed so that hay.item()
hasn’t been matched yet. On a fail, the state of hay is undefined.Sourcefn all_matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> Vec<usize>
fn all_matches<'a, H: HaystackOf<'a, I>>(hay: &mut H) -> Vec<usize>
Produces a Vec of all valid haystack states produced as the result of a valid match at the
start of
hay, used to implement backtracking. The Vec is produced in reverse priority
order, so the last match has the highest priority. After calling all_matches, the state of
hay itself is undefined. Read moreSourcefn captures<'a, H: HaystackOf<'a, I>>(
hay: &mut H,
caps: &mut IndexedCaptures,
) -> bool
fn captures<'a, H: HaystackOf<'a, I>>( hay: &mut H, caps: &mut IndexedCaptures, ) -> bool
Sourcefn all_captures<'a, H: HaystackOf<'a, I>>(
hay: &mut H,
caps: &mut IndexedCaptures,
) -> Vec<(usize, IndexedCaptures)>
fn all_captures<'a, H: HaystackOf<'a, I>>( hay: &mut H, caps: &mut IndexedCaptures, ) -> Vec<(usize, IndexedCaptures)>
Produces a Vec of all valid captures (and accompanying haystack states) present at the start
of
hay. Used to implement backtracking for capturing methods. As with
all_matches, the resulting Vec is produced in reverse priority
order. After calling all_captures, the state of hay and caps are undefined. Read moreAuto Trait Implementations
impl Freeze for Beginning
impl RefUnwindSafe for Beginning
impl Send for Beginning
impl Sync for Beginning
impl Unpin for Beginning
impl UnwindSafe for Beginning